@@ -16,42 +16,6 @@ pub mod names {
     pub const ALL: [&str; 13] = [AH, AL, BH, BL, CH, CL, DH, DL, AX, BX, CX, DX, FLAGS];
 }
 
-pub mod offset {
-    use crate::registers::id;
-    use crate::LangError;
-    use crate::LangError::InvalidRegisterId;
-
-    pub const AH: usize = 0;
-    pub const AL: usize = 1;
-    pub const BH: usize = 2;
-    pub const BL: usize = 3;
-    pub const CH: usize = 4;
-    pub const CL: usize = 5;
-    pub const DH: usize = 6;
-    pub const DL: usize = 7;
-    pub const FLAGS: usize = 8;
-    pub const AX: usize = AH;
-    pub const BX: usize = BH;
-    pub const CX: usize = CH;
-    pub const DX: usize = DH;
-
-    pub const fn from_id(id: u8) -> Result<u8, LangError> {
-        let offset = match id as usize {
-            id::AH | id::AX => AH,
-            id::BH | id::BX => BH,
-            id::CH | id::CX => CH,
-            id::DH | id::DX => DH,
-            id::AL => AL,
-            id::BL => BL,
-            id::CL => CL,
-            id::DL => DL,
-            id::FLAGS => FLAGS,
-            _ => return Err(InvalidRegisterId(id)),
-        };
-        Ok(offset as u8)
-    }
-}
-
 pub mod id {
     use crate::registers::names;
     use crate::LangError;
@@ -143,23 +107,6 @@ mod test {
 
     #[test]
     fn check_ids_align() {
-        assert_eq!(offset::from_id(id::AH as u8).unwrap(), offset::AH as u8);
-        assert_eq!(offset::from_id(id::AL as u8).unwrap(), offset::AL as u8);
-        assert_eq!(offset::from_id(id::BH as u8).unwrap(), offset::BH as u8);
-        assert_eq!(offset::from_id(id::BL as u8).unwrap(), offset::BL as u8);
-        assert_eq!(offset::from_id(id::CH as u8).unwrap(), offset::CH as u8);
-        assert_eq!(offset::from_id(id::CL as u8).unwrap(), offset::CL as u8);
-        assert_eq!(offset::from_id(id::DH as u8).unwrap(), offset::DH as u8);
-        assert_eq!(offset::from_id(id::DL as u8).unwrap(), offset::DL as u8);
-        assert_eq!(offset::from_id(id::AX as u8).unwrap(), offset::AX as u8);
-        assert_eq!(offset::from_id(id::BX as u8).unwrap(), offset::BX as u8);
-        assert_eq!(offset::from_id(id::CX as u8).unwrap(), offset::CX as u8);
-        assert_eq!(offset::from_id(id::DX as u8).unwrap(), offset::DX as u8);
-        assert_eq!(
-            offset::from_id(id::FLAGS as u8).unwrap(),
-            offset::FLAGS as u8
-        );
-
         assert_eq!(id::to_name(id::AH as u8).unwrap(), names::AH);
         assert_eq!(id::to_name(id::AL as u8).unwrap(), names::AL);
         assert_eq!(id::to_name(id::BH as u8).unwrap(), names::BH);
@@ -193,6 +140,5 @@ mod test {
     fn check_invalid_values() {
         assert!(id::from_name("gsgad").is_err());
         assert!(id::to_name(255).is_err());
-        assert!(offset::from_id(255).is_err());
     }
 }
